@@ -340,7 +340,7 @@ retry:
 bool ScriptInterp::step(const char *trapname)
 {
 	unsigned long mask, cmask;
-	bool rtn;
+	bool rtn, sync;
 	Symbol *sym = NULL;
 
 	if(!image)
@@ -401,7 +401,12 @@ retry:
 		sym = getEntry("script.error");
 	if(sym)
 		sym->flags.type = TRIGGER;
+	sync = script[stack].line->sync;
+	if(sync)
+		setExclusive(true);
 	rtn = execute(script[stack].line->method);
+	if(sync)
+		setExclusive(false);
 	if(sym)
 		sym->flags.type = NORMAL;
 	return rtn;
