@@ -442,6 +442,14 @@ SharedMemPager(paging)
 	trigger = NULL;
 }
 
+void ScriptSymbol::setExclusive(bool enable)
+{
+	if(enable)
+		enterMutex();
+	else
+		leaveMutex();
+}
+
 Script::Symbol *ScriptSymbol::getTrigger(void)
 {
 	Symbol *sym;
@@ -1138,6 +1146,11 @@ void ScriptImage::purge(void)
 void ScriptImage::commit(void)
 {
 	cmds->enterMutex();
+	if(cmds->active)
+	{
+		if(!cmds->active->refcount)
+			delete cmds->active;
+	}
 	cmds->active = this;
 	cmds->leaveMutex();
 }
@@ -1443,7 +1456,7 @@ int ScriptImage::compile(istream *str, char *name, const char *scrname)
 	char *command, *token;
 	char *args[33];
 	char *err, *cp;
-	bool trapflag, errflag;
+	bool trapflag, errflag, syncflag;
 	int argc, i, key, tlen;
 	unsigned short count, number, total = 0;
 	Name *script;
@@ -1498,7 +1511,7 @@ compile:
 		if(!then)
 		{
 			cmask = 0;
-			errflag = false;
+			errflag = syncflag = false;
 			scrStream->getline(buffer + offset, sizeof(buffer) - 1 - offset);
 			if(scrStream->eof())
 				break;
@@ -1729,6 +1742,33 @@ compile:
 				continue;
 
 		ignore = false;
+		syncflag = false;
+
+retoken:
+		if(!token)
+			continue;
+
+		if(!stricmp(token, "optional") || !stricmp(token, "unsafe"))
+		{
+			ignore = true;
+			token = getToken();
+			goto retoken;
+		}
+
+		if(!stricmp(token, "exclusive"))
+		{
+			syncflag = true;
+			token = getToken();
+			goto retoken;
+		}
+
+		if(!stricmp(token, "error"))
+		{
+			errflag = true;
+			token = getToken();
+			goto retoken;
+		}
+			
 		if(*token == '@')
 		{
 			ignore = true;
@@ -1786,6 +1826,7 @@ compile:
 		line->args = (char **)alloc(sizeof(char *) * argc);
 		line->argc = --argc;
 		line->error = errflag;
+		line->sync = syncflag;
 		line->method = handler;
 		line->cmd = command;
 		line->loop = 0;
