@@ -68,6 +68,7 @@ class CCXX_CLASS_EXPORT ScriptInterp;
 #define SYMBOL_INDEX_SIZE 187
 #define SCRIPT_INDEX_SIZE KEYWORD_INDEX_SIZE
 #define	SCRIPT_PREPROCESSOR_OVERRIDE 1
+#define	SCRIPT_EXCLUSIVE_OVERRIDE 1
 
 class Script
 {
@@ -120,6 +121,7 @@ protected:
 		unsigned short line;
 		unsigned char argc;
 		bool error : 1;
+		bool sync : 1;
 		Method method;
 		char *cmd;
 		char **args;
@@ -622,6 +624,11 @@ public:
 	 */
 	virtual Symbol *getEntry(const char *symbol, int size = 0);
 
+	/**
+	 * Can be used to tie together an exclusive function...
+	 */
+	void setExclusive(bool enable);
+
 public:
 	/**
 	 * A virtual method used when "committing" symbol changes.
@@ -1333,6 +1340,14 @@ protected:
 	virtual void stepScheduler(const char *trapname)
 		{trap(trapname);};
 
+	/**
+	 * Set exclusive sync locking for interpreter.
+	 *
+	 * @param turn exclusive on or off.
+	 */
+	virtual void setExclusive(bool enable)
+		{return;};
+
 public:
 	/**
 	 * Search for symbols either thru the virtual global space
